require_relative 'pledge'
require_relative 'fundable'
module CrowdFund
	class Project
		include Fundable
		attr_accessor :name
		attr_reader :funding, :target

		def initialize(name, funding=0, target)
			@name= name
			@funding= funding
			@target= target
			@pledges_made= Hash.new(0)
		end

		def to_s
			"Project #{@name} has $#{@funding} in funding towards a goal of $#{@target}, we still need $#{funding_needed} to hit our goal."
		end

		def funded?
			@funding >= @target
		end

		def <=>(other)
			other.funding_needed <=> funding_needed
		end

		def pledges_made(pledge)
			@pledges_made[pledge.level] += pledge.amount
			puts "Project #{@name} received a #{pledge.level} pledge worth $#{pledge.amount}."
			puts "Project #{@name}'s pledges: #{@pledges_made}"
		end

		def each_pledge_donated
			@pledges_made.each do |level, amount|
				yield Pledges.new(level, amount)
			end
		end

		def funds
			@pledges_made.values.reduce(0, :+)
		end

		def funding_needed
			@target - @funding
		end

	end
end
	